PYHPECFM

**READ THIS FIRST**
This library is currently in alpha state and should not be used for production installations.
Support is not offered at this time, but GITHUB issues are welcome if bugs or potential feature
enhancements are found.

##Description

This is a sample python language binding for the HPE Composable Fabric Manager

note: The minimum version of CFM required is 5.0. This library will not work with prior versions
 of CFM or any version branded with the former Plexxi name.

Installation


Currently the pyhpecfm library is not available on Pypi. Manual installation is the only
method requiring users to first download this git repository locally and then running the install
command in the pyhpecfm folder where the setup.py is located.

pyhpecfm will be posted to pypi in the future.

`pip install -r requirements.txt`




